@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Logout Handler
 #
-# $Id: lonlogout.pm,v 1.24 2007/01/12 15:54:12 raeburn Exp $
+# $Id: lonlogout.pm,v 1.25 2007/03/01 23:14:12 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -66,7 +66,15 @@ sub handler {
 			 $env{'user.name'},
 			 $env{'user.home'},
 			 "Logout $ENV{'REMOTE_ADDR'}");
+
     &Apache::loncommon::content_type($r,'text/html');
+
+    #expire the cookie
+    my $c = new CGI::Cookie(-name    => 'lonID',
+			    -value   => '',
+			    -expires => '-10y',);
+    $r->header_out('Set-cookie' => $c);
+
     $r->send_http_header;
     return OK if $r->header_only;
 # -------------------------------------------------------- Menu script and info
