@@ -1,6 +1,6 @@
 # functions to glue school database system into Lon-CAPA for 
 # automated enrollment
-# $Id: localenroll.pm,v 1.20 2007/05/14 20:15:23 raeburn Exp $
+# $Id: localenroll.pm,v 1.21 2007/07/25 20:43:48 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -512,7 +512,7 @@ sub allusers_info {
 ###############################
 # sub get_userinfo
 #
-# Incoming data: four required arguments and two optional arguments
+# Incoming data: four required arguments and t optional arguments
 # Retrieves institutional data for a single user either by username
 # if $uname is included as second argument, or by ID if $id is 
 # included as a third argument.  Either (b) or (c) must be provided. 
@@ -531,6 +531,13 @@ sub allusers_info {
 #                 if a single ID matches multiple usernames.
 # (f) $types - optional reference to array which contains 
 #              institutional types to check.
+# (g) $srchby - optional if $uname or $id defined, otherwise required.
+#               Allowed values include: 1. lastfirst, 2. last, 3. uname
+#               corresponding to searches by 1. lastname,firstname;
+#               2. lastname; 3. username
+# (h) $srchterm - optional if $uname or $id defined, otherwise required
+#                String to search for.
+# (i) $srchtype - optional. Allowed value: contains
 #
 # returns 1 parameter - ('ok' or other value).
 # side effects - populates the $instusers and $instids refs to hashes.
@@ -541,7 +548,8 @@ sub allusers_info {
 ###############################
 
 sub get_userinfo {
-    my ($dom,$uname,$id,$instusers,$instids,$types) = @_;
+    my ($dom,$uname,$id,$instusers,$instids,$types,
+        $srchby,$srchterm,$srchtype) = @_;
     my $outcome = 'ok';
     return $outcome;
 }
