@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # chemical equation style response
 #
-# $Id: chemresponse.pm,v 1.71 2006/12/04 21:23:01 albertel Exp $
+# $Id: chemresponse.pm,v 1.73 2007/04/18 00:48:06 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -327,6 +327,10 @@ sub end_organicresponse {
 	}
 	$result.=&Apache::response::answer_footer('organicresponse');
     }
+    if ($target eq 'web') {
+	&Apache::response::setup_prior_tries_hash(\&format_prior_answer_organic,
+						  ['molecule'])
+    }
 
     if ($target eq 'grade' || $target eq 'web' || $target eq 'answer' || 
 	$target eq 'tex' || $target eq 'analyze') {
@@ -336,6 +340,14 @@ sub end_organicresponse {
     return $result;
 }
 
+sub format_prior_answer_organic {
+    my ($mode,$answer,$other_data) = @_;
+    my $result=&mt('Smile representation: "[_1]"','<tt>'.$answer.'</tt>');
+    my $jme=$other_data->[0];
+    $result.=&jme_img($jme,$answer,400);
+    return $result;
+}
+
 sub start_organicstructure {
     my ($target,$token,$tagstack,$parstack,$parser,$safeeval,$style)=@_;
     my $result;
@@ -542,6 +554,9 @@ sub end_reactionresponse {
 	}
 	$result.=&Apache::response::answer_footer('reactionresponse');
     }
+    if ($target eq 'web') {
+	&Apache::response::setup_prior_tries_hash(\&format_prior_response_reaction);
+    }
 
     if ($target eq 'grade' || $target eq 'web' || $target eq 'answer' || 
 	$target eq 'tex' || $target eq 'analyze') {
@@ -551,6 +566,12 @@ sub end_reactionresponse {
     return $result;
 }
 
+sub format_prior_response_reaction {
+    my ($mode,$answer) =@_;
+    return '<span class="LC_prior_reaction">'.
+	    &HTML::Entities::encode($answer,'"<>&').'</span>';
+}
+
 sub start_chem {
     my ($target,$token,$tagstack,$parstack,$parser,$safeeval,$style) = @_;
     my $result = '';
