@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # essay (ungraded) style responses
 #
-# $Id: essayresponse.pm,v 1.82 2007/04/17 23:25:09 albertel Exp $
+# $Id: essayresponse.pm,v 1.83 2007/08/10 20:09:30 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -148,7 +148,8 @@ sub end_essayresponse {
 		    my ($symb,$crsid,$domain,$name)=
 			&Apache::lonnet::whichuser();
 		    if ($crsid) {
-			my $akey=$name.'.'.$domain.'.'.$crsid;
+			my $akey=join('.',&escape($name),&escape($domain),
+				      &escape($crsid));
 			my $essayurl=
 			    &Apache::lonnet::declutter($ENV{'REQUEST_URI'});
 			my ($adom,$aname,$apath)=
