@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Interface routines to MAXIMA CAS
 #
-# $Id: lonmaxima.pm,v 1.17 2007/07/11 18:50:33 albertel Exp $
+# $Id: lonmaxima.pm,v 1.21 2007/08/14 21:54:54 riegler Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -62,7 +62,9 @@ sub blacklisted {
     my ($cmd)=@_;
     foreach my $forbidden ('save','load','plot','lisp','includ','compil',
 			   'file','batch','stringout','translat','stout',
-			   'stin','block','system','concat') {
+			   'stin','block','system','concat','read','inchar',
+			   'outchar','ttyoff','with_stdout','writefile',
+			   'reset') {
 	if ($cmd=~/$forbidden/s) { return 1; }
     } 
     return 0;
