@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Sending messages
 #
-# $Id: lonnotify.pm,v 1.25 2006/11/01 22:22:31 www Exp $
+# $Id: lonnotify.pm,v 1.26 2007/03/08 01:58:45 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -787,7 +787,7 @@ sub store_mail {
                         $attachmenturl,$recipients,undef,undef,'dcmail');
 
 # Store in dc email db files on primary library server for domain.
-    my $server = $Apache::lonnet::domain_primary{$domain};
+    my $server = &Apache::lonnet::domain($domain,'primary');
     if (defined($server)) {
         unless (&Apache::lonnet::dcmailput($domain,$msgid,$message,$server) 
                                                             eq 'ok') {
