@@ -1,7 +1,7 @@
 #!/usr/bin/perl
 # CGI-script to run LaTeX, dvips, ps2ps, ps2pdf etc.
 #
-# $Id: printout.pl,v 1.120 2007/01/19 20:22:33 albertel Exp $
+# $Id: printout.pl,v 1.125 2007/05/10 09:53:39 foxr Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -39,6 +39,7 @@ use Apache::loncommon();
 use Apache::lonlocal;
 use Apache::lonmsg();
 use LONCAPA::Enrollment;
+use LONCAPA::Configuration;
 
 use strict;
 
@@ -128,8 +129,8 @@ sub send_error_mail {
 	    foreach my $line (@$texfile) {
 		$message .= "$line\n";
 	    }
-	    my (undef, %receivers) = &Apache::lonfeedback::decide_receiver(undef, 0,
-									  1,1,1);
+	    my (undef, %receivers) = &Apache::lonmsg::decide_receiver(undef, 0,
+								      1,1,1);
 	    # print "<br /> sending...section:  $env{'request.course.sec'}";
 	    foreach my $dest (keys %receivers) {
 		# print "<br /> dest is $dest";
@@ -161,6 +162,8 @@ Your cookie information is incorrect.
 END
     return;
 }
+
+my %perlvar=%{&LONCAPA::Configuration::read_conf('loncapa.conf')};
  &Apache::lonlocal::get_language_handle();
  &Apache::loncommon::content_type(undef,'text/html');
 
@@ -188,9 +191,9 @@ END
 print "<a href=\"$backref\"><b>Return</b></a> to last resource.<br /><br />";
 
   my $figfile = $texfile;
-  $figfile =~ s/^([^\.]+printout)[^t]+\.tex/$1\.dat/;
+  $figfile =~ s/^(.*_printout)_\d+_\d+_\d+\.tex/$1\.dat/;
   my $duefile = $texfile;
-  $duefile =~ s/^([^\.]+printout)[^t]+\.tex/$1\.due/;
+  $duefile =~ s/^(.*_printout)_\d+_\d+_\d+\.tex/$1\.due/;
   #do we have figures?
   # print "Figure file: $figfile\n";
   if (-e $figfile) {
@@ -214,13 +217,13 @@ print "<a href=\"$backref\"><b>Return</b></a> to last resource.<br /><br />";
 	      # $eps_f =~ s/\.[^.]*$/\.eps/i;
 	      if ($eps_f=~/\/home\/([^\/]+)\/public_html\//) {
                   $eps_f=~s/\/home\/([^\/]+)\/public_html/$1/;
-		  $eps_f = '/home/httpd/prtspool/'.$eps_f;
-	      } elsif ($eps_f=~/$Apache::lonnet::perlvar{'lonDocRoot'}\/res\//) {
-		  $eps_f=~m/$Apache::lonnet::perlvar{'lonDocRoot'}\/res\/(.+)/;
-		  $eps_f = '/home/httpd/prtspool/'.$1;
-	      } elsif ($eps_f=~/$Apache::lonnet::perlvar{'lonUsersDir'}\//) {
-		  $eps_f=~/$Apache::lonnet::perlvar{'lonUsersDir'}\/([^\/]+)\/\w\/\w\/\w\/(.+)/;
-		  $eps_f = '/home/httpd/prtspool/'.$1.'/'.$2;
+		  $eps_f = $perlvar{'lonPrtDir'}.'/'.$eps_f;
+	      } elsif ($eps_f=~/$perlvar{'lonDocRoot'}\/res\//) {
+		  $eps_f=~m/$perlvar{'lonDocRoot'}\/res\/(.+)/;
+		  $eps_f = $perlvar{'lonPrtDir'}.'/'.$1;
+	      } elsif ($eps_f=~/$perlvar{'lonUsersDir'}\//) {
+		  $eps_f=~/$perlvar{'lonUsersDir'}\/([^\/]+)\/\w\/\w\/\w\/(.+)/;
+		  $eps_f = $perlvar{'lonPrtDir'}.'/'.$1.'/'.$2;
 	      }
 	      $eps_f  =~ s/ /\_/g; # Spaces are problematic for system commands and LaTeX.
 	      # 
@@ -253,7 +256,7 @@ print "<a href=\"$backref\"><b>Return</b></a> to last resource.<br /><br />";
 		  if ($advanced_role) {
 		      my $prettyname=$not_eps;
 		      $prettyname=~s|/home/([^/]+)/public_html|/priv/$1|;
-		      $prettyname=~s|$Apache::lonnet::perlvar{'lonDocRoot'}/|/|;
+		      $prettyname=~s|$perlvar{'lonDocRoot'}/|/|;
 		      &Apache::lonhtmlcommon::Update_PrgWin('',\%prog_state,
 							    'Converting to EPS '.$prettyname);
 		  }
@@ -441,7 +444,7 @@ foreach $texfile (@texfile) {
 	      print "</pre>\n";
 	      # print "<br /> Advanced role <br />";
               print "<b><big>The link to ";
-              $logfilename=~s/\/home\/httpd//;
+              $logfilename=~s{^\Q$perlvar{'lonPrtDir'}\E}{/prtspool};
 	      print "<a href=\"$logfilename\">Your log file </a></big></b>";
 	      print "\n";
               #link tooriginal LaTeX file (included according Michael Hamlin desire)
@@ -454,7 +457,7 @@ foreach $texfile (@texfile) {
 	      print $tex_temporary_file '<html><head><title>LOGFILE</title></head><body><pre>'.$body_tex_file.'</pre></body></html>'."\n";
 	      print "<br /><br />";
 	      print "<b><big>The link to ";
-	      $texfile=~s/\/home\/httpd//;
+              $texfile=~s{^\Q$perlvar{'lonPrtDir'}\E}{/prtspool};
 	      print "<a href=\"$texfile\">Your original LaTeX file </a></big></b>";
 	      print "\n";
 	      my $help_text = &Apache::loncommon::help_open_topic("Print_Resource", "Help on printing");
@@ -559,7 +562,7 @@ foreach $texfile (@texfile) {
 	      #print("<br /> Missing fonts file is: $missfonts_file");
 	      if (-e $missfonts_file) {
 		  #print("<br />Missing fonts file exists\n");
-		  &create_missing_fonts($missfonts_file);
+		  &create_missing_fonts($missfonts_file,\%prog_state);
 		  &busy_wait_command("$comma $name_file 1>/dev/null 2>/dev/null",
 				     "for $status_statement dvips generated missing fonts",
 				     \%prog_state, $new_name_file);
@@ -612,7 +615,7 @@ foreach $texfile (@texfile) {
 	  if ($advanced_role) {  
 	      print "<br /><br />";
 	      print "<b><big>The link to ";
-	      $logfilename=~s/\/home\/httpd//;
+              $logfilename=~s{^\Q$perlvar{'lonPrtDir'}\E}{/prtspool};
 	      print "<a href=\"$logfilename\">Your log file </a></big></b>";
 	      print "\n";
 	      #link tooriginal LaTeX file (included according Michael Hamlin desire)
@@ -625,7 +628,7 @@ foreach $texfile (@texfile) {
 	      print $tex_temporary_file '<html><head><title>LOGFILE</title></head><body><pre>'.$body_tex_file.'</pre></body></html>'."\n";
 	      print "<br /><br />";
 	      print "<b><big>The link to ";
-	      $texfile=~s/\/home\/httpd//;
+              $texfile=~s{^\Q$perlvar{'lonPrtDir'}\E}{/prtspool};
 	      print "<a href=\"$texfile\">Your original LaTeX file </a></big></b>";
 	      print "\n";
 	  }
@@ -670,7 +673,7 @@ foreach $texfile (@texfile) {
 	  #print("<br /> Missing fonts file is: $missfonts_file");
 	  if (-e $missfonts_file) {
 	      #print("<br />Missing fonts file exists\n");
-	      &create_missing_fonts($missfonts_file);
+	      &create_missing_fonts($missfonts_file,\%prog_state);
 	      &busy_wait_command("$comma $name_file 1>/dev/null 2>/dev/null",
 				 "for $status_statement dvips generated missing fonts",
 				 \%prog_state, $new_name_file);
@@ -780,7 +783,7 @@ if ($number_of_files>1) {
     print("<pre>Zip Output:\n");
     system($statement);
     print("</pre>");
-    $zipfile=~s/\/home\/httpd//;
+    $zipfile=~s{^\Q$perlvar{'lonPrtDir'}\E}{/prtspool};
     print "<br /> A <a href=\"$zipfile\">ZIP file</a> of all the PDFs.";
 }
 if ($advanced_role) { &Apache::lonhtmlcommon::Close_PrgWin('',\%prog_state); }
@@ -997,7 +1000,7 @@ sub create_missing_fonts {
 	#print("<br />Creating fonts via command: $command");
 	&busy_wait_command("$command 1>/dev/null 2>/dev/null",
 			   "Creating missing font",
-			   $state, $command);
+			   $state);
 			   
     }
 
