@@ -2,7 +2,7 @@
 # The LearningOnline Network with CAPA
 # Handler to upload files into construction space
 #
-# $Id: lonupload.pm,v 1.34 2006/12/06 22:22:39 albertel Exp $
+# $Id: lonupload.pm,v 1.35 2007/05/02 01:34:23 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -99,7 +99,7 @@ sub phaseone {
 		      '<input type="hidden" name="datatoken" value="'.
 		      &upfile_store.'" />'.
 		      '<input type="hidden" name="uploaduname" value="'.$uname.
-		      '" />'.&mt('Store uploaded file as ').
+		      '" />'.&mt('Save uploaded file as ').
                       "<span class='LC_filename'>/priv/$uname/</span>".
                       '<input type="text" size="50" name="filename" value="'.$fn.
                       '" /><br />'.
@@ -112,7 +112,7 @@ sub phaseone {
 <br />
 <br />
 ');
-            $r->print('<input type="button" value="'.&mt('Store').'" onClick="javascript:verifyForm()"/></form>');
+            $r->print('<input type="button" value="'.&mt('Save').'" onClick="javascript:verifyForm()"/></form>');
 	    # Check for bad extension and warn user
 	    if ($fn=~/\.(\w+)$/ && 
 		(&Apache::loncommon::fileembstyle($1) eq 'hdn')) {
